@@ -1,7 +1,7 @@
 from py_desc.base import Base
 
 
-class NotFalseBoolean(Base):
+class TrueBoolean(Base):
 
     def __get__(self, instance, owner):
         return getattr(instance, self.name)
@@ -17,7 +17,7 @@ class NotFalseBoolean(Base):
         self.name = f'_{name.lower()}'
 
 
-class NotTrueBoolean(Base):
+class FalseBoolean(Base):
 
     def __get__(self, instance, owner):
         return getattr(instance, self.name)
